Learn R Programming

GWI (version 1.0.2)

di.fun: Function for DI

Description

The function computes the univariate Poisson dispersion index for a count random variable.

Usage

di.fun(X)

Arguments

X

A count random variable

Value

Returns

di

The Poisson dispersion index

Details

di.fun provides the univariate Poisson dispersion index (Fisher, 1934). We can refer to Tour<U+00E9> et al. (2020) for more details on the Poisson dispersion index.

References

Fisher, R.A. (1934). The effects of methods of ascertainment upon the estimation of frequencies, Annals of Eugenics 6, 13-25.

Tour<U+00E9>, A.Y., Dossou-Gb<U+00E9>t<U+00E9>, S. and Kokonendji, C.C. (2020). Asymptotic normality of the test statistics for relative dispersion and relative variation indexes, Journal of Applied Statistics 47, 2479-2491.

Examples

Run this code
# NOT RUN {
X<-c(6,7,8,9,8,4,7,6,12,8,0)
di.fun(X)
T<-c(61,72,83,94,85,46,77,68,129,80,10,12,12,3,4,5)
di.fun(T)
# }

Run the code above in your browser using DataLab