The function computes the inverse Gaussian variation index with shape parameter \(l\in (0,\infty)\).
Usage
viiG.fun(X, l)
Arguments
X
A positive continuous random variable
l
The shape parameter of the inverse Gaussian distribution
Value
Returns
viiG
The inverse Gaussian variation index
Details
viiG.fun computes the variation index with respect to the inverse Gaussian distribution. See Tour<U+00E9> et al. (2020) for more details.
References
Tour<U+00E9>, A.Y., Dossou-Gb<U+00E9>t<U+00E9>, S. and Kokonendji, C.C. (2020). Asymptotic normality of the test statistics for relative dispersion and relative variation indexes, Journal of Applied Statistics47, 2479-2491.