The function computes the univariate Poisson dispersion index for a count random variable.
Usage
di.fun(X)
Arguments
X
A count random variable
Value
Returns
di
The Poisson dispersion index
Details
di.fun provides the univariate Poisson dispersion index (Fisher, 1934). We can refer to Tour<U+00E9> et al. (2020) for more details on the Poisson dispersion index.
References
Fisher, R.A. (1934). The effects of methods of ascertainment upon the estimation of frequencies, Annals of Eugenics6, 13-25.
Tour<U+00E9>, A.Y., Dossou-Gb<U+00E9>t<U+00E9>, S. and Kokonendji, C.C. (2020). Asymptotic normality of the test statistics for relative dispersion and relative variation indexes, Journal of Applied Statistics47, 2479-2491.